generate_X_syn.RdGenerate data from synthetic clinical trial data with dimension n and 30 variables.
generate_X_syn(n)Number of observations
A data frame of predictors
The data are generated based on the data-set data_syn which is not exported from the package namespace. This data-set was generated from pooled set of clinical trial data using the synthpop function from the synthpop R package. data_syn has 1934 rows and 30 variables. Variable names have been removed. Continuous variables have been scaled to the interval [0,1], levels of the categorical variable have been blinded. For information on the synthetic data which synthpop generates from, see the supplementary material of the XYZ reference.
X <- generate_X_syn(n=100)
#> Warning: In your synthesis there are numeric variables with 5 or fewer levels: X10.
#> Consider changing them to factors. You can do it using parameter 'minnumlevels'.